@@ -1,4 +1,4 @@
-from .ns_util import *
+from .ns_util import *  # isort: skip
 from .cut import *
 from .git import *
 from .man import *
@@ -15,5 +15,5 @@ __all__ = [
     "stash_transfer_site_manifest",
     "yaml_manifests",
     "get_yaml_manifest",
-    "change_build_dir"
+    "change_build_dir",
 ]
